@@ -18,11 +18,11 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: debug.h,v 1.11 2002/09/05 19:37:53 nalin Exp $"
-
 #ifndef vte_debug_h_included
 #define vte_debug_h_included
 
+#ident "$Id: debug.h,v 1.14 2002/12/10 22:36:29 nalin Exp $"
+
 G_BEGIN_DECLS
 
 typedef enum {
@@ -35,7 +35,10 @@ typedef enum {
 	VTE_DEBUG_SELECTION	= 1 << 6,
 	VTE_DEBUG_SUBSTITUTION	= 1 << 7,
 	VTE_DEBUG_RING		= 1 << 8,
-	VTE_DEBUG_PTY		= 1 << 9
+	VTE_DEBUG_PTY		= 1 << 9,
+	VTE_DEBUG_CURSOR	= 1 << 10,
+	VTE_DEBUG_KEYBOARD	= 1 << 11,
+	VTE_DEBUG_LIFECYCLE	= 1 << 12
 } VteDebugFlags;
 
 void _vte_debug_parse_string(const char *string);
